Learn R Programming

DrugUtilisation (version 1.3.1)

restrictIncidentCohortDoc: Helper for consistent documentation of restrictIncident in cohort summaries.

Description

Helper for consistent documentation of restrictIncident in cohort summaries.

Arguments

restrictIncident

Whether to include only target cohort records that start during the analysis period. If FALSE, all target cohort records that overlap with the study period will be included.