Summarise patient-level drug utilisation cohorts using data mapped to the Observational Medical Outcomes Partnership (OMOP) common data model. New users and prevalent users cohorts can be generated and their characteristics, indication and drug use summarised.
Maintainer: Martí Català [email protected] (ORCID)
Authors:
Yuchen Guo [email protected] (ORCID)
Kim Lopez-Guell [email protected] (ORCID)
Edward Burn [email protected] (ORCID)
Nuria Mercade-Besora [email protected] (ORCID)
Xihang Chen [email protected] (ORCID)
Other contributors:
Mike Du [email protected] (ORCID) [contributor]
Xintong Li [email protected] (ORCID) [contributor]
Marta Alcalde-Herraiz [email protected] (ORCID) [contributor]
Useful links: