- cdm
A cdm_reference object.
- name
Name of the new cohort table, it must be a length 1 character
vector.
- ingredient
Accepts both vectors and named lists of ingredient names.
For a vector input, e.g., c("acetaminophen", "codeine"), it generates a
cohort table with descendant concept codes for each ingredient, assigning
unique cohort_definition_id. For a named list input, e.g., list(
"test_1" = c("simvastatin", "acetaminophen"), "test_2" = "metformin"),
it produces a cohort table based on the structure of the input, where
each name leads to a combined set of descendant concept codes for the
specified ingredients, creating distinct cohort_definition_id for each
named group.
- gapEra
Number of days between two continuous exposures to be
considered in the same era.
- subsetCohort
Cohort table to subset.
- subsetCohortId
Cohort definition IDs to use from subsetCohort.
- numberExposures
Whether to include 'number_exposures' (number of drug
exposure records between indexDate and censorDate).
- daysPrescribed
Whether to include 'days_prescribed' (number of days
prescribed used to create each era).
- ...
Arguments to be passed to
CodelistGenerator::getDrugIngredientCodes().